# Installation

Install ToolMate AI, by running:

To set up virtual environment (recommended):

> mkdir -p ~/apps/toolmate

> cd ~/apps/toolmate

> python3 -m venv toolmate

> source toolmate/bin/activate

To install:

> pip install --upgrade toolmate

To run:

> toolmate

# Notes to Windows Users

Windows may also need to install cmake, rust and Microsoft Visual C++ 14.0 or greater.

For more information, read: https://github.com/eliranwong/letmedoit/wiki/Installation#windows-users

# Notes to ChromeOS Users

Enable Linux container in your Chrome OS first

https://github.com/eliranwong/ChromeOSLinux#turn-on-linux

Use the Linux terminal to install `toolmate`